{
    "command": "murano-engine --config-file /etc/murano/murano.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/murano.conf",
            "dest": "/etc/murano/murano.conf",
            "owner": "murano",
            "perm": "0644"
        }
    ]
}
