{
    "command": "cinder-backup --config-file /etc/cinder/cinder.conf",
    "config_files": [
        {
            "source": "{{ container_config_directory }}/cinder.conf",
            "dest": "/etc/cinder/cinder.conf",
            "owner": "cinder",
            "perm": "0600"
        }{% if cinder_backend_ceph | bool %},
        {
            "source": "{{ container_config_directory }}/ceph.*",
            "dest": "/etc/ceph/",
            "owner": "cinder",
            "perm": "0700",
            "optional": {{ (not cinder_backend_ceph | bool) | string | lower }}
        }{% endif %}
    ]
}
